@@ -69,7 +69,7 @@ class TestPowerVMDriverInit(test.TestCase):
         self.flags(disk_driver='localdisk', group='powervm')
         self.flags(host='host1', my_ip='127.0.0.1')
 
-    @mock.patch('nova_powervm.virt.powervm.driver.NovaEventHandler')
+    @mock.patch('nova_powervm.virt.powervm.event.PowerVMNovaEventHandler')
     @mock.patch('pypowervm.adapter.Adapter')
     @mock.patch('pypowervm.adapter.Session')
     def test_get_adapter(self, mock_session, mock_adapter, mock_evt_handler):
@@ -181,17 +181,20 @@ class TestPowerVMDriver(test.TestCase):
         self.assertTrue(
             self.drv.session.get_event_listener.return_value.shutdown.called)
 
-    def test_get_volume_connector(self):
+    @mock.patch('nova_powervm.virt.powervm.volume.get_iscsi_initiator')
+    def test_get_volume_connector(self, mock_initiator):
         """Tests that a volume connector can be built."""
+        mock_initiator.return_value = 'iscsi_initiator'
 
         self.flags(volume_adapter='fibre_channel', group='powervm')
         vol_connector = self.drv.get_volume_connector(mock.Mock())
         self.assertIsNotNone(vol_connector['wwpns'])
         self.assertIsNotNone(vol_connector['host'])
+        self.assertEqual('iscsi_initiator', vol_connector['initiator'])
 
         self.flags(volume_adapter='iscsi', group='powervm')
         vol_connector = self.drv.get_volume_connector(mock.Mock())
-        self.assertIsNotNone(vol_connector['initiator'])
+        self.assertEqual('iscsi_initiator', vol_connector['initiator'])
 
     def test_setup_disk_adapter(self):
         # Ensure we can handle upper case option and we instantiate the class
@@ -336,7 +339,7 @@ class TestPowerVMDriver(test.TestCase):
             self.apt, self.drv.host_wrapper, self.inst, self.inst.get_flavor(),
             nvram=None, slot_mgr=self.slot_mgr)
         self.assertTrue(mock_pwron.called)
-        self.assertFalse(mock_pwron.call_args[1]['synchronous'])
+        self.assertTrue(mock_pwron.call_args[1]['synchronous'])
         # Assert that tasks that are not supposed to be called are not called
         self.assertFalse(mock_conn_vol.called)
         self.assertFalse(mock_crt_cfg_drv.called)
@@ -371,7 +374,7 @@ class TestPowerVMDriver(test.TestCase):
 
         # Power on was called
         self.assertTrue(mock_pwron.called)
-        self.assertFalse(mock_pwron.call_args[1]['synchronous'])
+        self.assertTrue(mock_pwron.call_args[1]['synchronous'])
         self.scrub_stg.assert_called_with(mock.ANY, self.stg_ftsk,
                                           lpars_exist=True)
 
@@ -419,7 +422,7 @@ class TestPowerVMDriver(test.TestCase):
                                          nvram=None, slot_mgr=self.slot_mgr)
         # Power on was called
         self.assertTrue(mock_pwron.called)
-        self.assertFalse(mock_pwron.call_args[1]['synchronous'])
+        self.assertTrue(mock_pwron.call_args[1]['synchronous'])
 
         # Check that the connect volume was called
         self.assertEqual(2, self.vol_drv.connect_volume.call_count)
@@ -483,7 +486,7 @@ class TestPowerVMDriver(test.TestCase):
                                          nvram=None, slot_mgr=self.slot_mgr)
         # Power on was called
         self.assertTrue(mock_pwron.called)
-        self.assertFalse(mock_pwron.call_args[1]['synchronous'])
+        self.assertTrue(mock_pwron.call_args[1]['synchronous'])
 
         # Check that the connect volume was called
         self.assertEqual(2, self.vol_drv.connect_volume.call_count)
@@ -532,7 +535,7 @@ class TestPowerVMDriver(test.TestCase):
                                          nvram=None, slot_mgr=self.slot_mgr)
         # Power on was called
         self.assertTrue(mock_pwron.called)
-        self.assertFalse(mock_pwron.call_args[1]['synchronous'])
+        self.assertTrue(mock_pwron.call_args[1]['synchronous'])
 
         # Check that the connect volume was called
         self.assertEqual(2, self.vol_drv.connect_volume.call_count)
@@ -652,7 +655,7 @@ class TestPowerVMDriver(test.TestCase):
 
         # Power on was called
         self.assertTrue(mock_pwron.called)
-        self.assertFalse(mock_pwron.call_args[1]['synchronous'])
+        self.assertTrue(mock_pwron.call_args[1]['synchronous'])
 
         # Validate the rollbacks were called
         self.assertEqual(2, self.vol_drv.disconnect_volume.call_count)
@@ -704,7 +707,7 @@ class TestPowerVMDriver(test.TestCase):
 
         # Power on was called
         self.assertTrue(mock_pwron.called)
-        self.assertFalse(mock_pwron.call_args[1]['synchronous'])
+        self.assertTrue(mock_pwron.call_args[1]['synchronous'])
 
         # Check that the connect volume was called
         self.assertEqual(2, self.vol_drv.connect_volume.call_count)
@@ -758,7 +761,7 @@ class TestPowerVMDriver(test.TestCase):
             self.inst_ibmi.get_flavor(), nvram=None, slot_mgr=self.slot_mgr)
         self.assertTrue(mock_update_lod_src.called)
         self.assertTrue(mock_pwron.called)
-        self.assertFalse(mock_pwron.call_args[1]['synchronous'])
+        self.assertTrue(mock_pwron.call_args[1]['synchronous'])
         # Assert that tasks that are not supposed to be called are not called
         self.assertFalse(mock_conn_vol.called)
         self.assertFalse(mock_crt_cfg_drv.called)
@@ -1506,7 +1509,7 @@ class TestPowerVMDriver(test.TestCase):
         self.assertTrue(mock_disk_dvr.create_disk_from_image.called)
         self.assertTrue(mock_disk_dvr.connect_disk.called)
         self.assertTrue(mock_task_pwr.power_on.called)
-        self.assertFalse(mock_task_pwr.power_on.call_args[1]['synchronous'])
+        self.assertTrue(mock_task_pwr.power_on.call_args[1]['synchronous'])
 
     @mock.patch('nova_powervm.virt.powervm.vm')
     @mock.patch('nova_powervm.virt.powervm.tasks.vm.vm')
@@ -1521,7 +1524,7 @@ class TestPowerVMDriver(test.TestCase):
         self.assertTrue(mock_disk_dvr.disconnect_image_disk.called)
         self.assertTrue(mock_disk_dvr.delete_disks.called)
         self.assertTrue(mock_task_pwr.power_on.called)
-        self.assertFalse(mock_task_pwr.power_on.call_args[1]['synchronous'])
+        self.assertTrue(mock_task_pwr.power_on.call_args[1]['synchronous'])
 
     @mock.patch('nova_powervm.virt.powervm.driver.LOG')
     def test_log_op(self, mock_log):
@@ -1936,6 +1939,10 @@ class TestPowerVMDriver(test.TestCase):
     def test_rollbk_lpm_dest(self):
         self.drv.rollback_live_migration_at_destination(
             'context', self.lpm_inst, 'network_info', 'block_device_info')
+        mock_rollback = self.lpm.rollback_live_migration_at_destination
+        mock_rollback.assert_called_once_with(
+            'context', self.lpm_inst, 'network_info', 'block_device_info',
+            destroy_disks=True, migrate_data=None)
         self.assertRaises(
             KeyError, lambda: self.drv.live_migrations[self.lpm_inst.uuid])
 
@@ -1949,6 +1956,20 @@ class TestPowerVMDriver(test.TestCase):
         self.lpm.post_live_migration_at_source.assert_called_once_with(
             'network_info')
 
+    @mock.patch('nova_powervm.virt.powervm.vm.power_off')
+    def test_power_off(self, mock_power_off):
+        self.drv.power_off(self.inst)
+        mock_power_off.assert_called_once_with(
+            self.drv.adapter, self.inst, self.drv.host_uuid,
+            force_immediate=True, timeout=None)
+
+        # Long timeout (retry interval means nothing on powervm)
+        mock_power_off.reset_mock()
+        self.drv.power_off(self.inst, timeout=500, retry_interval=10)
+        mock_power_off.assert_called_once_with(
+            self.drv.adapter, self.inst, self.drv.host_uuid,
+            force_immediate=False, timeout=500)
+
     def test_post_live_mig_dest(self):
         self.drv.post_live_migration_at_destination(
             'context', self.lpm_inst, 'network_info')
@@ -2047,68 +2068,3 @@ class TestPowerVMDriver(test.TestCase):
         mock_bk_dev.return_value = 'info'
         self.assertEqual('info',
                          self.drv._get_block_device_info('ctx', self.inst))
-
-
-class TestNovaEventHandler(test.TestCase):
-    def setUp(self):
-        super(TestNovaEventHandler, self).setUp()
-        self.mock_driver = mock.Mock()
-        self.handler = driver.NovaEventHandler(self.mock_driver)
-
-    @mock.patch('nova.context.get_admin_context', mock.MagicMock())
-    @mock.patch.object(vm, 'get_instance')
-    @mock.patch.object(vm, 'get_vm_qp')
-    def test_events(self, mock_qprops, mock_get_inst):
-        # Test events
-        event_data = [
-            {
-                'EventType': 'NEW_CLIENT',
-                'EventData': '',
-                'EventID': '1452692619554',
-                'EventDetail': '',
-            },
-            {
-                'EventType': 'MODIFY_URI',
-                'EventData': 'http://localhost:12080/rest/api/uom/Managed'
-                             'System/c889bf0d-9996-33ac-84c5-d16727083a77',
-                'EventID': '1452692619555',
-                'EventDetail': 'Other',
-            },
-            {
-                'EventType': 'MODIFY_URI',
-                'EventData': 'http://localhost:12080/rest/api/uom/Managed'
-                             'System/c889bf0d-9996-33ac-84c5-d16727083a77/'
-                             'LogicalPartition/794654F5-B6E9-4A51-BEC2-'
-                             'A73E41EAA938',
-                'EventID': '1452692619563',
-                'EventDetail': 'ReferenceCode,Other',
-            },
-            {
-                'EventType': 'MODIFY_URI',
-                'EventData': 'http://localhost:12080/rest/api/uom/Managed'
-                             'System/c889bf0d-9996-33ac-84c5-d16727083a77/'
-                             'LogicalPartition/794654F5-B6E9-4A51-BEC2-'
-                             'A73E41EAA938',
-                'EventID': '1452692619566',
-                'EventDetail': 'RMCState,PartitionState,Other',
-            },
-            {
-                'EventType': 'MODIFY_URI',
-                'EventData': 'http://localhost:12080/rest/api/uom/Managed'
-                             'System/c889bf0d-9996-33ac-84c5-d16727083a77/'
-                             'LogicalPartition/794654F5-B6E9-4A51-BEC2-'
-                             'A73E41EAA938',
-                'EventID': '1452692619566',
-                'EventDetail': 'NVRAM',
-            },
-        ]
-
-        mock_qprops.return_value = pvm_bp.LPARState.RUNNING
-        mock_get_inst.return_value = powervm.TEST_INST1
-
-        self.handler.process(event_data)
-        mock_get_inst.assert_called_once_with(mock.ANY, '794654F5-B6E9-'
-                                              '4A51-BEC2-A73E41EAA938')
-
-        self.assertTrue(self.mock_driver.emit_event.called)
-        self.assertTrue(self.mock_driver.nvram_mgr.store.called)
