@@ -942,7 +942,10 @@ class PowerVMDriver(driver.ComputeDriver):
                                waiting for it to shutdown
         """
         self._log_operation('power_off', instance)
-        vm.power_off(self.adapter, instance, self.host_uuid)
+        force_immediate = (timeout == 0)
+        timeout = timeout or None
+        vm.power_off(self.adapter, instance, self.host_uuid,
+                     force_immediate=force_immediate, timeout=timeout)
 
     def power_on(self, context, instance, network_info,
                  block_device_info=None):
@@ -1128,11 +1131,9 @@ class PowerVMDriver(driver.ComputeDriver):
         # The host ID
         connector = {'host': CONF.host}
 
-        # The WWPNs in case of FC connection.
+        # Get the contents from the volume driver
         vol_drv = self._get_inst_vol_adpt(ctx.get_admin_context(),
                                           instance)
-
-        # The WWPNs in case of FC connection.
         if vol_drv is not None:
 
             if CONF.powervm.volume_adapter.lower() == "fibre_channel":
@@ -1141,7 +1142,8 @@ class PowerVMDriver(driver.ComputeDriver):
                 if wwpn_list is not None:
                     connector["wwpns"] = wwpn_list
             connector['host'] = vol_drv.host_name()
-            connector['initiator'] = vol_drv.host_name()
+            connector['initiator'] = vol_attach.get_iscsi_initiator(
+                self.adapter)
         return connector
 
     def migrate_disk_and_power_off(self, context, instance, dest,
