@@ -26,7 +26,6 @@ from nova_powervm.virt.powervm.volume import driver as v_driver
 from nova_powervm.virt.powervm.volume import volume as volume
 from pypowervm import const as pvm_const
 from pypowervm.tasks import hdisk
-from pypowervm.tasks import partition
 from pypowervm.utils import transaction as tx
 from pypowervm.wrappers import virtual_io_server as pvm_vios
 
@@ -52,19 +51,13 @@ class IscsiVolumeAdapter(volume.VscsiVolumeAdapter,
         super(IscsiVolumeAdapter, self).__init__(
             adapter, host_uuid, instance, connection_info, stg_ftsk=stg_ftsk)
 
-        # iSCSI volumes are assumed to be on the novalink partition
-        mgmt_part = partition.get_mgmt_partition(adapter)
-        vios_uuid = mgmt_part.uuid
-        self.initiator_name = hdisk.discover_iscsi_initiator(
-            adapter, vios_uuid)
-
     @classmethod
     def vol_type(cls):
         """The type of volume supported by this type."""
         return 'iscsi'
 
     def host_name(self):
-        return self.initiator_name
+        return CONF.host
 
     @classmethod
     def min_xags(cls):
@@ -107,22 +100,22 @@ class IscsiVolumeAdapter(volume.VscsiVolumeAdapter,
         password = self.connection_info["data"]["auth_password"]
         user = self.connection_info["data"]["auth_username"]
         target_name = "ISCSI-" + iqn.split(":")[1]
-        device_name = hdisk.discover_iscsi(
+        device_name, udid = hdisk.discover_iscsi(
             self.adapter, host_ip, user, password, iqn, vios_w.uuid)
         slot, lua = slot_mgr.build_map.get_vscsi_slot(vios_w, device_name)
-        if device_name is not None:
+        if device_name is not None and udid is not None:
             device_name = '/dev/' + device_name
             # Found a hdisk on this Virtual I/O Server.  Add the action to
             # map it to the VM when the stg_ftsk is executed.
             with lockutils.lock(hash(self)):
                 self._add_append_mapping(
                     vios_w.uuid, device_name, lpar_slot_num=slot, lua=lua,
-                    target_name=target_name)
+                    target_name=target_name, udid=udid)
 
             # Save the devname for the disk in the connection info.  It is
             # used for the detach.
             self._set_devname(device_name)
-            self._set_udid(target_name)
+            self._set_udid(udid)
 
             LOG.debug('Device attached: %s', device_name)
 
